@@ -7,6 +7,7 @@ __title__ = "SIESTAstepper"
 __author__ = "Eftal Gezer"
 __license__ = "GNU GPL v3"
 __copyright__ = "Copyright 2022, Eftal Gezer"
-__version__ = "0.4.1"
+__version__ = "1.0.0"
 
-from .core import run, run_next, ani_to_fdf, xyz_to_fdf, cwd, analysis, log, cores, conda
+from .core import run, single_run, run_next, run_interrupted, single_run_interrupted, make_directories, copy_files, \
+    ani_to_fdf, xyz_to_fdf, merge_ani, cwd, analysis, log, cores, conda, contfiles
